@@ -1,5 +1,5 @@
 package Bio::Roary::Output::QueryGroups;
-$Bio::Roary::Output::QueryGroups::VERSION = '3.2.6';
+$Bio::Roary::Output::QueryGroups::VERSION = '3.2.7';
 # ABSTRACT:  Output the groups of the union of a set of input isolates
 
 
@@ -42,10 +42,14 @@ sub _build__groups_freq {
     for my $filename ( @{ $self->input_filenames } ) {
         my $genes = $self->analyse_groups->_files_to_genes->{$filename};
         
+		my %file_groups_seen;
         for my $gene ( @{$genes} ) {
           next if(!defined($gene));
           next if(!defined($self->analyse_groups->_genes_to_groups->{$gene}));
-            push(@{$groups_freq{ $self->analyse_groups->_genes_to_groups->{$gene} }}, $gene);
+		  next if(defined($file_groups_seen{$self->analyse_groups->_genes_to_groups->{$gene}}));
+		  
+          push(@{$groups_freq{ $self->analyse_groups->_genes_to_groups->{$gene} }}, $gene);
+          $file_groups_seen{$self->analyse_groups->_genes_to_groups->{$gene}} = 1;
         }
     }
 
@@ -132,7 +136,7 @@ Bio::Roary::Output::QueryGroups - Output the groups of the union of a set of inp
 
 =head1 VERSION
 
-version 3.2.6
+version 3.2.7
 
 =head1 SYNOPSIS
 
